@@ -446,7 +446,7 @@ Info_authenticate_eq(VALUE self, VALUE passwd_arg)
     }
     else
     {
-        RemoveImageOption(info, "authenticate");
+        DeleteImageOption(info, "authenticate");
     }
 #else
     if (info->authenticate)
@@ -1750,6 +1750,8 @@ Info_page_eq(VALUE self, VALUE page_arg)
         info->page = NULL;
         return page_arg;
     }
+    magick_free(info->page);
+
     info->page = geometry;
 
     RB_GC_GUARD(geom_str);
@@ -2292,7 +2294,7 @@ Info_view_eq(VALUE self, VALUE view_arg)
     }
     else
     {
-        RemoveImageOption(info, "fpx:view");
+        DeleteImageOption(info, "fpx:view");
     }
 #else
     if (info->view)
