@@ -6,12 +6,12 @@ describe Magick, '.formats' do
     expect(described_class.formats).to be_instance_of(Hash)
     described_class.formats.each do |f, v|
       expect(f).to be_instance_of(String)
-      expect(v).to match(/[\*\+\srw]+/)
+      expect(v).to match(/[*+\srw]+/)
     end
 
     described_class.formats do |f, v|
       expect(f).to be_instance_of(String)
-      expect(v).to match(/[\*\+\srw]+/)
+      expect(v).to match(/[*+\srw]+/)
     end
   end
 end
